@@ -52,6 +52,22 @@ class CfnNamedQuery(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type
 
         jsii.create(CfnNamedQuery, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnNamedQuery":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -230,6 +246,22 @@ class CfnWorkGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
         jsii.create(CfnWorkGroup, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any) -> "CfnWorkGroup":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
